@@ -2,14 +2,14 @@
 #' 
 #' \code{exp_est} exports wave objects of an extended selection table as sound files
 #' @usage exp_est(X, file.name = NULL, path = NULL, single.file = FALSE, 
-#' selection.table = TRUE, pb = TRUE, normalize = TRUE, parallel = 1)  
+#' selection.table = TRUE, pb = TRUE, normalize = TRUE, parallel = 1, wave.object = FALSE)  
 #' @param  X object of class 'extended_selection_table' (objects produced by \code{\link[warbleR]{selection_table}}). More details about these objects can be found on \href{https://marce10.github.io/2018/05/15/Extended_selection_tables.html}{this link}.
 #' @param file.name character string indicating the name of the sound file (if \code{single.file = TRUE}) 
 #' and/or the selection table (if \code{selection.table = TRUE}). Default is \code{NULL}.
 #' @param path A character string indicating the path of the directory where sound files and/or selection table will be saved. If not provided the
 #' function uses the current working directory. Default is \code{NULL}.
 #' @param single.file Logical argument to control if all wave objects are pooled together in a 
-#' single sound file (if \code{TRUE}) or each one as an individual sound file (default). If 
+#' single sound file (if \code{TRUE}) or each one as an individual sound file (if \code{FALSE}, default). If 
 #' exporting a single sound file the files are pasted in the same sequences as in the extended selection table. Note that to create a single sound file ALL WAVE OBJECTS IN 'X" MUST HAVE THE SAME SAMPLE RATE (check \code{attributes(X)$check.res$sample.rate}) and ideally the same bit depth (although not strictly required). If that is not the case, sample rate can be homogenize using the \code{\link[warbleR]{resample_est}} from the warbleR package.
 #' @param selection.table Logical argument to determine if a Raven sound selection table ('.txt' file) is also exported. 
 #' Default is \code{TRUE}. If \code{FALSE} then selection table is return as an object in the R environment. If exporting multiple sound files (if \code{single.file = FALSE}) the function still exports a single selection table (in this case a multiple sound selection table).
@@ -17,6 +17,7 @@
 #' @param normalize Logical argument to control if wave objects are individually normalized before exporting (or before being pasted together if \code{single.file = TRUE}). Normalization rescales amplitude values to a 16 bit dynamic range. Default is \code{FALSE}.
 #' @param parallel Numeric. Controls whether parallel computing is applied.
 #'  It specifies the number of cores to be used. Default is 1 (i.e. no parallel computing).
+#' @param wave.object Logical argument to control if ONLY a single wave object is returned in the R environment (TRUE) instead of a wave file in the working directory (and a selection table if \code{selection.table = TRUE}). Default is \code{FALSE}.
 #' @return Sound file(s) are saved in the provided path or current working directory. If \code{selection.table = TRUE} a Raven sound selection table with the data in 'X' will also be saved.
 #' @details The function takes wave objects contained as attributes in extended selection 
 #' tables and saves them as sound files in '.wav' format. A single or several sound files can be produced (see 'single.file' argument).  In addition, a Raven sound selection table can be saved along with the sound files. The exported selection table can be open in Raven for exploring/manipulating selections in 'X'. 
@@ -40,20 +41,31 @@
 #' }
 #' @name exp_est
 #' 
-#' @author Marcelo Araya-Salas (\email{marceloa27@@gmail.com})
+#' @author Marcelo Araya-Salas (\email{marcelo.araya@@ucr.ac.cr})
 #last modification on mar-11-2019
 
 exp_est <- function(X, file.name = NULL, path = NULL, single.file = FALSE,  
                     selection.table = TRUE, pb = TRUE, normalize = TRUE, 
-                    parallel = 1)
+                    parallel = 1, wave.object = FALSE)
 {
   
   #check path to working directory
-  if (is.null(path)) path <- getwd() else if (!dir.exists(path)) stop("'path' provided does not exist") 
+  if (is.null(path)) path <- getwd() else if (!dir.exists(path)) stop("'path' provided does not exist") else
+    path <- normalizePath(path)
+ 
+  # if wave object then single file and no selection table
+  if (wave.object) {
+    
+    # single file
+    single.file <- TRUE
+   
+    # no selection table
+    selection.table <- FALSE
+  }
+  
   
   # if file.name 
-  if(is.null(file.name) & selection.table) stop("'file.name' must be provided when 'selection.table' is TRUE")
-  
+  if (is.null(file.name) & selection.table) stop("'file.name' must be provided when 'selection.table' is TRUE")
   # set progress bar back to original
   on.exit(pbapply::pboptions(type = .Options$pboptions$type), 
           add = TRUE)
@@ -81,6 +93,7 @@ exp_est <- function(X, file.name = NULL, path = NULL, single.file = FALSE,
       wvs <- lapply(wvs, tuneR::normalize, unit = "16", rescale = TRUE)
     
       # add .wav at the end of file.name if not included
+    if (!wave.object)
       if(!grepl("\\.wav$", file.name, ignore.case = TRUE)) file.name <- paste0(file.name, ".wav")
     
     # get first wave object  
@@ -91,7 +104,8 @@ exp_est <- function(X, file.name = NULL, path = NULL, single.file = FALSE,
     for(i in 2:length(wvs))
       sngl.wv <- seewave::pastew(wave1 = wvs[[i]], wave2 = sngl.wv, output = "Wave")
   
-    # save single wave
+    # save single wave 
+    if(!wave.object)
     suppressWarnings(tuneR::writeWave(object = sngl.wv, filename = file.path(path, file.name), extensible = FALSE))
     } else
 
@@ -163,7 +177,8 @@ exp_est <- function(X, file.name = NULL, path = NULL, single.file = FALSE,
       #fix sound file names in st
       st$sound.files <- ifelse(grepl("\\.wav$", st$sound.files, ignore.case = TRUE), st$sound.files, paste0( st$sound.files, ".wav"))
     
-      
+      if(wave.object)
+         return(sngl.wv) else
                return(st)
       }
 }
